aboutsummaryrefslogtreecommitdiff
path: root/include/acpi/aclocal.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/acpi/aclocal.h')
-rw-r--r--include/acpi/aclocal.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/include/acpi/aclocal.h b/include/acpi/aclocal.h
index 030e641115c..52c6a202586 100644
--- a/include/acpi/aclocal.h
+++ b/include/acpi/aclocal.h
@@ -365,7 +365,7 @@ struct acpi_gpe_xrupt_info
struct acpi_gpe_xrupt_info *previous;
struct acpi_gpe_xrupt_info *next;
struct acpi_gpe_block_info *gpe_block_list_head; /* List of GPE blocks for this xrupt */
- u32 interrupt_level; /* System interrupt level */
+ u32 interrupt_number; /* System interrupt number */
};
@@ -737,6 +737,7 @@ struct acpi_parse_state
****************************************************************************/
#define PCI_ROOT_HID_STRING "PNP0A03"
+#define PCI_EXPRESS_ROOT_HID_STRING "PNP0A08"
struct acpi_bit_register_info
{